Coverage for C:\src\imod-python\imod\mf6\interfaces\ipointdatapackage.py: 85%

1 from abc import abstractmethod

2

3 import numpy as np

4 from numpy.typing import NDArray

5

6 from imod.mf6.interfaces.ipackagebase import IPackageBase

7

8

9 class IPointDataPackage(IPackageBase):

10 """

11 Interface for packages for which the data is defined by x and y coordinates independent of the domain definition.

12 """

13

14 @property

15 @abstractmethod

16 def x(self) -> NDArray[np.float64]:

17 raise NotImplementedError

18

19 @property

20 @abstractmethod

21 def y(self) -> NDArray[np.float64]:

22 raise NotImplementedError